/*
Brecky Morris and UCSC, 6.22.2020
*/

#include <TI_ADS8699.h>
#include <stdio.h>
#include <SPI.h>

// Set Constants
#define ADC_CHIP_SELECT   A1  // set pin 10 as the chip select for the ADC
#define ADC_RESET         A2  // reset gets set to high

TI_ADS8699 adc(ADC_CHIP_SELECT, ADC_RESET);

//Start setup function:
void setup() {

  Serial.begin(115200);

  delay(5000);

  Serial.println("Hello");

  // disable the LoRa radio
  pinMode(8, OUTPUT);
  digitalWrite(8, HIGH);

  adc.begin();

  // a couple of bad readings at first
  for (int index = 0; index < 10; index++) {
    adc.readADC(UNIPOLAR_3x_VREF);
  }
}

/* range selection
BIPOLAR_3x_VREF                     1 // 0000b = ±3 × VREF
BIPOLAR_2POINT5x_VREF               2 // 0001b = ±2.5 × VREF
BIPOLAR_1POINT5x_VREF               3 // 0010b = ±1.5 × VREF
BIPOLAR_1POINT25x_VREF              4 // 0011b = ±1.25 × VREF
BIPOLAR_POINT625x_VREF              5 // 0100b = ±0.625 × VREF
UNIPOLAR_3x_VREF                    6 // 1000b = 3 × VREF
UNIPOLAR_2POINT5x_VREF              7 // 1001b = 2.5 × VREF
UNIPOLAR_1POINT5x_VREF              8 // 1010b = 1.5 × VREF
UNIPOLAR_1POINT25x_VREF             9 // 1011b = 1.25 × VREF
*/

void loop() {

  double voltageSum = 0.0;
  for (int index = 0; index < 1; index++) {
    double voltage = adc.readADC(UNIPOLAR_3x_VREF);
    voltageSum += voltage;
  }

  double voltageAverage = voltageSum / 1.0;
 
  Serial.print("voltage: ");
  Serial.print(voltageAverage, 3);
  Serial.println(" mV");

  delay(1000);
}
